What's new in iParrot 1.1.4?
===========================
Release Date: 2021-09-23

Release Feature:
* request: support data parameter in GET method 
  

What's new in iParrot 1.1.3?
===========================
Release Date: 2021-05-07

Release Feature:
* logger: add encoding when new FileHandler


What's new in iParrot 1.1.2?
===========================
Release Date: 2020-11-17

Release Feature:
* optimize some exception handling


What's new in iParrot 1.1.1?
===========================
Release Date: 2019-11-18

Release Feature:
* add `parrot template` command to generate test cases template and example
* add `parrot replace` command to batch update test cases according to specified rules
* add `parrot home` and `parrot doc` commands to show github info
* add `time.spent` related assertions, e.g. `time_lt`
* update readme

Version 1.1.0 was deprecated because of a careless bug.

What's new in iParrot 1.0.6?
===========================
Release Date: 2019-11-08

Release Feature:
* `parrot record` has the `-ae, --auto-extract` parameter added
* fix bugs on simple_assert and log-mode
* update readme

What's new in iParrot 1.0.5?
===========================
Release Date: 2019-10-30

Release Feature:
* record -s supports both har file and directory
* solve some problems about response format
* fix bugs
* update readme

What's new in iParrot 1.0.4?
===========================
Release Date: 2019-10-25

Release Feature:
* change replay -o, --output to -t, --target
* solve some problems about file encoding and content structure
* fix bugs

What's new in iParrot 1.0.3?
===========================
Release Date: 2019-10-24

Release Feature:
* update README
* remove python 2.7 support
* fix bugs

What's new in iParrot 1.0.2?
===========================
Release Date: 2019-09-29

Release Feature:
* update setup.py
* fix bugs

What's new in iParrot 1.0.0?
===========================
Release Date: 2019-09-27

Release Feature:
* Build automated test solution for http requests based on recording and playback
* For details, go to `README.md`
